@@ -7,17 +7,16 @@ class SectionTypeChoices(Enum):
     waterstandlocaties = "WATERSTANDLOCATIES"
     mswlocaties = "MSWLOCATIES"
 
+    @classmethod
+    def get_all(cls):
+        return [x.value for x in cls.__members__.values()]
+
 
 IDMAP_SECTIONS_MAPPER = {
     IdMapChoices.idmap_opvl_water_hymos.value: {
-        SectionTypeChoices.kunstwerken.value: [
-            {"section_end": "<!--WATERSTANDSLOCATIES-->"}
-        ],
+        SectionTypeChoices.kunstwerken.value: [{"section_end": "<!--WATERSTANDSLOCATIES-->"}],
         SectionTypeChoices.waterstandlocaties.value: [
-            {
-                "section_start": "<!--WATERSTANDSLOCATIES-->",
-                "section_end": "<!--OVERIG-->",
-            }
+            {"section_start": "<!--WATERSTANDSLOCATIES-->", "section_end": "<!--OVERIG-->",}
         ],
     },
     IdMapChoices.idmap_opvl_water.value: {
@@ -32,18 +31,10 @@ IDMAP_SECTIONS_MAPPER = {
             },
         ],
         SectionTypeChoices.waterstandlocaties.value: [
-            {
-                "section_start": "<!--WATERSTANDSLOCATIES (old CAW id)-->",
-                "section_end": "<!--MSW (old CAW id)-->",
-            },
-            {
-                "section_start": "<!--WATERSTANDSLOCATIES (new CAW id)-->",
-                "section_end": "<!--MSW (new CAW id)-->",
-            },
-        ],
-        SectionTypeChoices.mswlocaties.value: [
-            {"section_start": "<!--MSW (new CAW id)-->"}
+            {"section_start": "<!--WATERSTANDSLOCATIES (old CAW id)-->", "section_end": "<!--MSW (old CAW id)-->",},
+            {"section_start": "<!--WATERSTANDSLOCATIES (new CAW id)-->", "section_end": "<!--MSW (new CAW id)-->",},
         ],
+        SectionTypeChoices.mswlocaties.value: [{"section_start": "<!--MSW (new CAW id)-->"}],
     },
 }
 SECTION_TYPE_PREFIX_MAPPER = {
